@@ -5,7 +5,7 @@ from typing import Dict, List
 
 
 def get_list() -> Dict[str, str]:
-    wordlist = pkgutil.get_data(__name__, 'diceware.wordlist.asc').decode('utf-8')
+    wordlist = pkgutil.get_data(__name__, 'eff_large_wordlist.txt').decode('utf-8')
     return {
         number: phrase
         for [number, phrase] in [line.strip().split('\t') for line in wordlist.strip().split('\n')]
@@ -28,9 +28,15 @@ def generate_password(length: int) -> str:
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument('length', nargs=1, type=int)
+    parser.add_argument(
+        'length',
+        nargs='?',
+        default=6,
+        type=int,
+        help='Number of words in the passphrase (defaults to 6)',
+    )
     parsed = parser.parse_args()
-    print(generate_password(parsed.length[0]))
+    print(generate_password(parsed.length))
 
 
 if __name__ == '__main__':
